==> theia-0.1.3-py3-none-any.whl: theia/aws/database/opensearch.py <==
import pulumi
from pulumi_aws import opensearch, get_caller_identity, get_region
from pulumi.output import Output
import json

from typing import Optional, List, Mapping
from pydantic.dataclasses import dataclass, ConfigDict
from theia import ResourceOptions
from theia.definitions import THEIA_VERSION
from theia._registry import StackRegistry, GlobalTags
from theia.utils.errors import TheiaConfigurationError

@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class OpenSearchSettings:
    subnet_ids: Optional[List[str]] = None
    security_group_ids: Optional[List[str | Output[str]]] = None
    access_policies: Optional[str] = None
    advanced_options: Optional[Mapping[str, str]] = None
    username: Optional[str] = None
    password: Optional[str] = None
    arn: Optional[str] = None
    instance_count: Optional[int] = 1
    instance_type: Optional[str] = "t3.small.search"
    ebs_enabled: Optional[bool] = True
    volume_type: Optional[str] = "gp3"
    volume_size: Optional[int] = 10
    node_encyption: Optional[bool] = True
    multi_az_with_standby_enabled: Optional[bool] = False
    auto_software_update_enabled: Optional[bool] = False
    encryption_at_rest: Optional[bool] = True
    domain_advanced_security_enabled: Optional[bool] = True
    internal_user_database_enabled: Optional[bool] = True
    tls_security_policy: Optional[str] = 'Policy-Min-TLS-1-2-2019-07'

    def __post_init__(self):
        pass
        if self.subnet_ids is not None:
            if self.instance_count < len(self.subnet_ids):
                raise TheiaConfigurationError(
                    f"You must specify exactly {self.instance_count} subnet"
                )
    
class OpenSearch(pulumi.ComponentResource):
    def __init__(
        self,
        resource_name: str,
        domain_name: str,
        version: str,
        settings: Optional[OpenSearchSettings] = OpenSearchSettings(),
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> None:
        super().__init__("theia:aws:opensearch", resource_name, None, opts)

        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        vpcoptions= opensearch.DomainVpcOptionsArgs(
            subnet_ids=settings.subnet_ids,
            security_group_ids=settings.security_group_ids
        )

        caller_identity = get_caller_identity()

        os_args = opensearch.DomainArgs(
            domain_name=domain_name,
            engine_version=version,
            advanced_security_options=opensearch.DomainAdvancedSecurityOptionsArgs(
                enabled=settings.domain_advanced_security_enabled,
                internal_user_database_enabled=settings.internal_user_database_enabled,
                master_user_options= opensearch.DomainAdvancedSecurityOptionsMasterUserOptionsArgs(
                master_user_name=settings.username,
                master_user_password=settings.password)
            ),
            access_policies=pulumi.Output.all(caller_identity.account_id, get_region().name).apply(lambda args: json.dumps({
                "Version": "2012-10-17",
                "Statement": [{
                    "Effect": "Allow",
                    "Principal": {
                        "AWS": "*"
                    },
                    "Action": "es:*",
                    "Resource": f"arn:aws:es:{args[1]}:{args[0]}:domain/{domain_name}/*"
                }]
            })),
            advanced_options=settings.advanced_options,
            cluster_config=opensearch.DomainClusterConfigArgs(
                multi_az_with_standby_enabled=settings.multi_az_with_standby_enabled,
                instance_count=settings.instance_count,
                instance_type=settings.instance_type
            ),
            domain_endpoint_options=opensearch.DomainDomainEndpointOptionsArgs(
                enforce_https=True,
                tls_security_policy=settings.tls_security_policy
            ),
            ebs_options=opensearch.DomainEbsOptionsArgs(
                ebs_enabled= settings.ebs_enabled,
                volume_type= settings.volume_type,
                volume_size=settings.volume_size
            ),
            encrypt_at_rest=opensearch.DomainEncryptAtRestArgs(
                enabled = settings.encryption_at_rest
            ),
            node_to_node_encryption=opensearch.DomainNodeToNodeEncryptionArgs(
                enabled=settings.node_encyption
            ),
            software_update_options=opensearch.DomainSoftwareUpdateOptionsArgs(
                auto_software_update_enabled = settings.auto_software_update_enabled
            ),
            vpc_options=vpcoptions,
            tags=merged_tags
        )
        self.elasticsearch_domain = opensearch.Domain(
            resource_name,
            args=os_args,
            opts=ResourceOptions(parent=self)
        )

        pulumi.export(
            f"opensearch---{resource_name}",
            {
                "arn": self.elasticsearch_domain.arn,
                "endpoint": self.elasticsearch_domain.endpoint
            }
        )

        self.register_outputs({})

    @staticmethod
    def import_(stack: str, resource_name: str) -> opensearch.Domain:
        stack_ref = StackRegistry.get(stack_name=stack)
        opensearch = stack_ref.get_output(name=f"opensearch---{resource_name}")
        return opensearch.Domain.get(domain_name=resource_name, arn=opensearch["arn"])

==> theia-0.1.5-py3-none-any.whl: theia/aws/database/opensearch.py <==
import pulumi
from pulumi_aws import opensearch, get_caller_identity, get_region
from pulumi.output import Output
import json

from typing import Optional, List, Mapping
from pydantic.dataclasses import dataclass, ConfigDict
from theia import ResourceOptions
from theia.definitions import THEIA_VERSION
from theia._registry import StackRegistry, GlobalTags
from theia.utils.errors import TheiaConfigurationError

@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class OpenSearchSettings:
    subnet_ids: Optional[List[str | Output[str]]] = None
    security_group_ids: Optional[List[str | Output[str]]] = None
    access_policies: Optional[str | Output[str]] = None
    advanced_options: Optional[Mapping[str, str]] = None
    username: Optional[str | Output[str]] = None
    password: Optional[str | Output[str]] = None
    arn: Optional[str| Output[str]] = None
    instance_count: Optional[int] = 1
    instance_type: Optional[str] = "t3.small.search"
    ebs_enabled: Optional[bool] = True
    volume_type: Optional[str] = "gp3"
    volume_size: Optional[int] = 10
    node_encyption: Optional[bool] = True
    multi_az_with_standby_enabled: Optional[bool] = False
    auto_software_update_enabled: Optional[bool] = False
    encryption_at_rest: Optional[bool] = True
    domain_advanced_security_enabled: Optional[bool] = True
    internal_user_database_enabled: Optional[bool] = True
    tls_security_policy: Optional[str] = 'Policy-Min-TLS-1-2-2019-07'

    def __post_init__(self):
        pass
        if self.subnet_ids is not None:
            if self.instance_count < len(self.subnet_ids):
                raise TheiaConfigurationError(
                    f"You must specify exactly {self.instance_count} subnet"
                )
    
class OpenSearch(pulumi.ComponentResource):
    def __init__(
        self,
        resource_name: str,
        domain_name: str,
        version: str,
        settings: Optional[OpenSearchSettings] = OpenSearchSettings(),
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> None:
        super().__init__("theia:aws:opensearch", resource_name, None, opts)

        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        vpcoptions= opensearch.DomainVpcOptionsArgs(
            subnet_ids=settings.subnet_ids,
            security_group_ids=settings.security_group_ids
        )

        caller_identity = get_caller_identity()

        os_args = opensearch.DomainArgs(
            domain_name=domain_name,
            engine_version=version,
            advanced_security_options=opensearch.DomainAdvancedSecurityOptionsArgs(
                enabled=settings.domain_advanced_security_enabled,
                internal_user_database_enabled=settings.internal_user_database_enabled,
                master_user_options= opensearch.DomainAdvancedSecurityOptionsMasterUserOptionsArgs(
                master_user_name=settings.username,
                master_user_password=settings.password)
            ),
            access_policies=pulumi.Output.all(caller_identity.account_id, get_region().name).apply(lambda args: json.dumps({
                "Version": "2012-10-17",
                "Statement": [{
                    "Effect": "Allow",
                    "Principal": {
                        "AWS": "*"
                    },
                    "Action": "es:*",
                    "Resource": f"arn:aws:es:{args[1]}:{args[0]}:domain/{domain_name}/*"
                }]
            })),
            advanced_options=settings.advanced_options,
            cluster_config=opensearch.DomainClusterConfigArgs(
                multi_az_with_standby_enabled=settings.multi_az_with_standby_enabled,
                instance_count=settings.instance_count,
                instance_type=settings.instance_type
            ),
            domain_endpoint_options=opensearch.DomainDomainEndpointOptionsArgs(
                enforce_https=True,
                tls_security_policy=settings.tls_security_policy
            ),
            ebs_options=opensearch.DomainEbsOptionsArgs(
                ebs_enabled= settings.ebs_enabled,
                volume_type= settings.volume_type,
                volume_size=settings.volume_size
            ),
            encrypt_at_rest=opensearch.DomainEncryptAtRestArgs(
                enabled = settings.encryption_at_rest
            ),
            node_to_node_encryption=opensearch.DomainNodeToNodeEncryptionArgs(
                enabled=settings.node_encyption
            ),
            software_update_options=opensearch.DomainSoftwareUpdateOptionsArgs(
                auto_software_update_enabled = settings.auto_software_update_enabled
            ),
            vpc_options=vpcoptions,
            tags=merged_tags
        )
        self.elasticsearch_domain = opensearch.Domain(
            resource_name,
            args=os_args,
            opts=ResourceOptions(parent=self)
        )

        pulumi.export(
            f"opensearch---{resource_name}",
            {
                "arn": self.elasticsearch_domain.arn,
                "endpoint": self.elasticsearch_domain.endpoint
            }
        )

        self.register_outputs({})

    @staticmethod
    def import_(stack: str, resource_name: str) -> opensearch.Domain:
        stack_ref = StackRegistry.get(stack_name=stack)
        opensearch = stack_ref.get_output(name=f"opensearch---{resource_name}")
        return opensearch.Domain.get(domain_name=resource_name, arn=opensearch["arn"])
